gleaph/search
Types
Specifies whether the search shall be continued or stopped.
pub type SearchNext(acc_t) {
Continue(acc: acc_t)
Stop(acc: acc_t)
}
Constructors
-
Continue(acc: acc_t) -
Stop(acc: acc_t)
Specifies whether the search shall be continued or stopped.
pub type SearchNext(acc_t) {
Continue(acc: acc_t)
Stop(acc: acc_t)
}
Continue(acc: acc_t)
Stop(acc: acc_t)